@@ -1,4 +1,4 @@
-/*
+ /*
  * src/client/player.c, part of Complete Goan (player program)
  * Copyright (C) 1995-1996 William Shubert
  * See "configure.h.in" for more copyright information.
@@ -37,7 +37,7 @@ static ButOut  newSort(But *but, int newSortType);
 static ButOut  listPressed(But *but, int line);
 static void  redrawLine(CliPlayerList *pl, int playerNum);
 static ButOut  matchPressed(But *but);
-
+static ButOut  observePressed(But *but);
 
 /**********************************************************************
  * Functions
@@ -99,7 +99,7 @@ void  cliPlayerList_openWin(CliPlayerList *gl)  {
   }
   cliPlayerList_sort(gl);
   cg = gl->data->cg;
-  winW = (butEnv_fontH(cg->env, 0) * 27) / 2 + 2 * cg->fontH +
+  winW = (butEnv_fontH(cg->env, 0) * 28) / 2 + 2 * cg->fontH +
     butEnv_stdBw(cg->env) * 8;
   winH = (clp_getDouble(cg->clp, "client.players.h") * cg->fontH + 0.5);
   str_init(&winName);
@@ -165,7 +165,7 @@ static void  expandPlayers(CliPlayerList *gl, int playerNum)  {
       str_init(&newPlayers[i].name);
       str_init(&newPlayers[i].rank);
       str_init(&newPlayers[i].idleTime);
-      newPlayers[i].match = NULL;
+      newPlayers[i].but = NULL;
       newPlayers[i].gameIn = -1;
     }
     if (gl->players)
@@ -263,7 +263,7 @@ static ButOut  destroy(ButWin *win)  {
   clp_setInt(cg->clp, "client.players.y", butWin_y(win));
   gl->win = NULL;
   for (i = 0;  i < gl->maxPlayers;  ++i)  {
-    gl->players[i].match = NULL;
+    gl->players[i].but = NULL;
   }
   return(0);
 }
@@ -393,9 +393,9 @@ void  cliPlayerList_disconnected(CliPlayerList *pl, const char *buf)  {
       --pl->sortEnd;
     if (pl->win)  {
       butList_changeLine(pl->list, playerNum, "");
-      if (pl->players[playerNum].match)  {
-	but_destroy(pl->players[playerNum].match);
-	pl->players[playerNum].match = NULL;
+      if (pl->players[playerNum].but)  {
+	but_destroy(pl->players[playerNum].but);
+	pl->players[playerNum].but = NULL;
       }
     }
   }
@@ -467,10 +467,12 @@ void  cliPlayerList_sort(CliPlayerList *pl)  {
 	break;
       getListEl(pl, i, &listEl);
       butList_changeLine(pl->list, i, str_chars(&listEl));
-      if (pl->players[i].match != NULL)
-	but_resize(pl->players[i].match, bw + physFontH * 7,
+      if (pl->players[i].but != NULL) {
+	but_resize(pl->players[i].but,
+		   bw + physFontH * (pl->players[i].matchBut ? 7 : 11),
 		   bw + physFontH * i,
-		   physFontH * 2, physFontH);
+		   physFontH * (pl->players[i].matchBut ? 2 : 3), physFontH);
+      }
     }
     if (i == 0)
       i = 1;
@@ -605,9 +607,9 @@ static void  redrawLine(CliPlayerList *pl, int playerNum)  {
     p = &pl->players[playerNum];
     getListEl(pl, playerNum, &pl->data->cmdBuild);
     if (p->state == cliPlayer_noPlayer)  {
-      if (p->match)  {
-	but_destroy(p->match);
-	p->match = NULL;
+      if (p->but)  {
+	but_destroy(p->but);
+	p->but = NULL;
       }
       if (playerNum == butList_len(pl->list) - 1)  {
 	for (lastPlayer = playerNum - 1;
@@ -626,27 +628,41 @@ static void  redrawLine(CliPlayerList *pl, int playerNum)  {
 			 butEnv_fontH(pl->data->cg->env, 0) +
 			 butEnv_stdBw(pl->data->cg->env) * 2, TRUE);
       }
-      if (p->match == NULL)  {
-	if ((p->state != cliPlayer_closed) && (p->gameIn == -1))  {
+      if (p->but) {
+	if (!((p->matchBut && (p->gameIn == -1) &&
+	       (p->state != cliPlayer_closed)) ||
+	      (!p->matchBut && (p->gameIn != -1)))) {
+	  but_destroy(p->but);
+	  p->but = NULL;
+	}
+      }
+      if (p->but == NULL)  {
+	if (p->gameIn != -1) {
+	  char label[10];
+	  sprintf(label, "P%d", p->gameIn);
+	  p->but = butCt_create(observePressed, pl, pl->swin->win, 3,
+				BUT_DRAWABLE|BUT_PRESSABLE, label);
+	  p->matchBut = FALSE;
+	} else if (p->state != cliPlayer_closed)  {
 	  state[0] = "?XO! "[p->state];
 	  state[1] = '\0';
-	  p->match = butCt_create(matchPressed, pl, pl->swin->win, 3,
-				  BUT_DRAWABLE|BUT_PRESSABLE, state);
+	  p->but = butCt_create(matchPressed, pl, pl->swin->win, 3,
+				BUT_DRAWABLE|BUT_PRESSABLE, state);
+	  p->matchBut = TRUE;
+	}
+	if (p->but != NULL) {
 	  env = pl->data->cg->env;
 	  physFontH = butEnv_fontH(env, 0);
 	  bw = butEnv_stdBw(env);
-	  but_resize(p->match, bw + physFontH * 7,
+	  but_resize(p->but, bw + physFontH * (p->matchBut ? 7 : 11),
 		     bw + physFontH * playerNum,
-		     physFontH * 2, physFontH);
+		     physFontH * (p->matchBut ? 2 : 3), physFontH);
 	}
       } else  {
-	if ((p->state == cliPlayer_closed) || (p->gameIn != -1))  {
-	  but_destroy(p->match);
-	  p->match = NULL;
-	} else  {
+	if (p->matchBut) {
 	  state[0] = "?XO! "[p->state];
 	  state[1] = '\0';
-	  butCt_setText(p->match, state);
+	  butCt_setText(p->but, state);
 	}
       }
     }
@@ -667,7 +683,7 @@ static ButOut  matchPressed(But *but)  {
    * If there were lots of buttons, hashing the but *'s or something would
    *   be a good idea.  But for now, a linear search is probably OK.
    */
-  for (playerNum = 0;  pl->players[playerNum].match != but;  ++playerNum)  {
+  for (playerNum = 0;  pl->players[playerNum].but != but;  ++playerNum)  {
     assert(playerNum < pl->maxPlayers);
   }
   p = &pl->players[playerNum];
@@ -701,6 +717,23 @@ static ButOut  matchPressed(But *but)  {
 }
 
 
+static ButOut observePressed(But *but) {
+  CliPlayerList *pl = but_packet(but);
+  CliPlayer *p;
+  int playerNum;
+  char message[100];
+
+  assert(MAGIC(pl));
+  for (playerNum = 0; pl->players[playerNum].but != but; ++playerNum) {
+    assert(playerNum < pl->maxPlayers);
+  }
+  p = &pl->players[playerNum];
+  if (p->gameIn != -1) {
+    pl->data->observeGame(pl->data->obPacket, p->gameIn);
+  }
+  return(0);
+}
+
 extern const char  *cliPlayerList_getRank(CliPlayerList *pl,
 					  const char *name)  {
   int  i;
