@@ -76,7 +76,7 @@ GoGame  *goGame_create(int size, GoRules rules, int handicap, float komi,
   game->moveNum = 0;
   game->maxMoves = 0;
   game->passCount = 0;
-  game->movesLen = 400;
+  game->movesLen = 5 /* 400 */;
   game->moves = wms_malloc(game->movesLen * sizeof(game->moves[0]));
   game->noLastMove = FALSE;
 
@@ -93,7 +93,9 @@ GoGame  *goGame_create(int size, GoRules rules, int handicap, float komi,
   game->state = goGameState_play;
 
   game->setWhoseMoveNum = -1;
-
+  game->disputeAlive = FALSE;
+  game->setWhoseMoveColor = 0;
+  game->disputedLoc = 0;
   if (game->handicap && goGame_forcedHandicapPlacement(game))
     goGame_addHandicapStones(game, game->board);
 
@@ -207,6 +209,7 @@ static void  goGame_updateForMove(GoGame *game, GoStone moveColor, int move)  {
   
   caps = goBoard_addStone(game->board, moveColor, move, NULL);
   ++game->moveNum;
+  assert(game->moveNum <= game->movesLen);
 
   /*
    * Update the list of hashes seen.
@@ -306,6 +309,7 @@ static bool  goGame_canMove(GoGame *game, GoStone s, int move)  {
   /* Check for a ko. */
   switch(goRules_ko[game->rules])  {
   case goRulesKo_super:
+    assert(game->moveNum <= game->movesLen);
     for (i = 0;  i < game->moveNum;  ++i)  {
       if (goHash_eq(game->moves[i].hash, newHash) &&
 	  (goGame_whoseTurnOnMove(game, i) == goStone_opponent(s)))  {
@@ -494,10 +498,11 @@ static GoBoard  *goGame_replay(GoGame *game, int moves, bool separateBoard)  {
   }
   if (game->handicap && goGame_forcedHandicapPlacement(game))
     goGame_addHandicapStones(game, b);
+  assert(moves <= game->movesLen);
   for (i = 0;  i < moves;  ++i)  {
-    if (separateBoard)
+    if (separateBoard) {
       goBoard_addStone(b, game->moves[i].color, game->moves[i].move, NULL);
-    else  {
+    } else {
       game->whoseMove = game->moves[i].color;
       if ((game->time.type == goTime_none) ||
 	  (game->moves[i].time.timeLeft >= 0))  {
@@ -506,8 +511,10 @@ static GoBoard  *goGame_replay(GoGame *game, int moves, bool separateBoard)  {
 	 *   game ended before the move could be made.
 	 */
 	goGame_updateForMove(game, game->whoseMove, game->moves[i].move);
-      } else
+      } else {
 	++game->moveNum;
+	assert(game->moveNum < game->movesLen);
+      }
     }
   }
   if (!separateBoard)  {
@@ -588,7 +595,7 @@ static void  addMoveToMoves(GoGame *game, GoStone moveColor, int move,
   GoGameMove  *newMoves;
   int  i;
 
-  if (moveNum == game->movesLen)  {
+  if (moveNum + 1 == game->movesLen)  {
     newMoves = wms_malloc(game->movesLen * 2 * sizeof(game->moves[0]));
     for (i = 0;  i < game->movesLen;  ++i)  {
       newMoves[i] = game->moves[i];
@@ -597,6 +604,7 @@ static void  addMoveToMoves(GoGame *game, GoStone moveColor, int move,
     game->moves = newMoves;
     game->movesLen *= 2;
   }
+  assert(moveNum + 1 < game->movesLen);
   game->moves[moveNum].move = move;
   game->moves[moveNum].color = moveColor;
 }
@@ -606,6 +614,8 @@ int  goGame_lastMove(GoGame *g)  {
   assert(MAGIC(g));
   if (g->noLastMove || (g->moveNum == 0))
     return(0);
+  assert(g->moveNum > 0);
+  assert(g->moveNum <= g->movesLen);
   return(g->moves[g->moveNum - 1].move);
 }
 
@@ -624,15 +634,17 @@ void  goGame_setBoard(GoGame *game, GoStone color, int loc)  {
 
 const GoTimer  *goGame_getTimer(const GoGame *game, GoStone color)  {
   if (color == game->whoseMove)  {
-    if (game->moveNum <= 1)
+    if (game->moveNum <= 1) {
       return(NULL);
-    else
+    } else {
       return(&game->moves[game->moveNum - 2].time);
+    }
   } else  {
-    if (game->moveNum <= 0)
+    if (game->moveNum <= 0) {
       return(NULL);
-    else
+    } else {
       return(&game->moves[game->moveNum - 1].time);
+    }
   }
 }
 
