@@ -644,14 +644,36 @@ static ButOut newTime(ButTimer *t)  {
 void  goban_updateTimeReadouts(Goban *g)  {
   GoStone  color;
   Str  newText;
+  int tLeft, stonesLeft;
 
   assert(MAGIC(g));
   str_init(&newText);
   goStoneIter(color)  {
     goTime_remainStr(&g->game->time, &g->timers[color], &newText);
     if (strcmp(str_chars(&newText),
-	       butText_get(g->playerInfos[color].timeOut)))
+	       butText_get(g->playerInfos[color].timeOut))) {
       butText_set(g->playerInfos[color].timeOut, str_chars(&newText));
+      tLeft = g->timers[color].timeLeft;
+      if ((g->cg->cgbuts.timeWarn > 0) &&
+	  goTime_low(&g->game->time,
+		     &g->timers[color], g->cg->cgbuts.timeWarn) &&
+	  ((tLeft & 1) == 0)) {
+	butText_setColor(g->playerInfos[color].timeOut, BUT_BLACK, FALSE);
+	butBoxFilled_setColors(g->playerInfos[color].timeBox,
+			       BUT_SHAD, BUT_LIT, BUT_WHITE);
+      } else {
+	butText_setColor(g->playerInfos[color].timeOut, CGBUTS_COLORREDLED,
+			 FALSE);
+	butBoxFilled_setColors(g->playerInfos[color].timeBox,
+			       BUT_SHAD, BUT_LIT, BUT_BLACK);
+      }
+    }
+    if (g->game->whoseMove != color) {
+      butText_setColor(g->playerInfos[color].timeOut, CGBUTS_COLORREDLED,
+		       FALSE);
+      butBoxFilled_setColors(g->playerInfos[color].timeBox,
+			     BUT_SHAD, BUT_LIT, BUT_BLACK);
+    }
   }
   str_deinit(&newText);
 }
