@@ -53,12 +53,12 @@ static const AbutHelpText  aboutAuthor[] = {
   {butText_just, 0, "   Thanks for trying out my program.  I hope you like "
    "it!"},
   {butText_just, 0, "   Special thanks to all cgoban testers, especially "
-   "to Eric Anderson, Dan Niles, Per-Eric Martin, Anthony Thyssen, "
+   "to Tomas Boman, Jean-Louis Martineau, "
+   "Eric Anderson, Dan Niles, Per-Eric Martin, Anthony Thyssen, "
    "Jan van der Steen, "
    "Eric Hoffman, Allen Tollin, Mel Melchner, Saito Takaaki, and "
-   "Matt Ritchie, who were "
-   "willing to debug cgoban on their systems and/or hack on the code to help "
-   "track down bugs for me."},
+   "Matt Ritchie, who either helped debug, wrote extra features for me, or "
+   "otherwise hacked on the code to help make cgoban what it is."},
 
   {butText_just, 0, ""},
   {butText_left, 0, NULL}};
