@@ -48,7 +48,7 @@ static ButOut  newSrvNum(But *but, int value);
 static ButOut  newName(But *but, const char *newVal);
 static ButOut  newProto(But *but, int newVal);
 static ButOut  newHiContrast(But *but, bool value);
-
+static ButOut newWarnLimit(But *but, const char *val);
 
 /**********************************************************************
  * Functions
@@ -68,6 +68,7 @@ Setup  *setup_create(Cgoban *cg,
   int  h, minH, bw;
   ButWin  *subwin;
   const char  *menuOpts[SETUP_MAXSERVERS + 1];
+  char tmpWarnLimit[10];
   
   assert(MAGIC(cg));
   setup = wms_malloc(sizeof(Setup));
@@ -191,6 +192,14 @@ Setup  *setup_create(Cgoban *cg,
 			       BUT_DRAWABLE|BUT_PRESSABLE,
 			       clp_getBool(cg->clp, "client.noTypo"));
 
+  setup->warnLabel = butText_create(subwin, 1, BUT_DRAWABLE,
+				    msg_warnLimit, butText_left);
+  i = clp_getInt(cg->clp, "client.warnLimit");
+  sprintf(tmpWarnLimit, "%d", i);
+  setup->warnLimit = butTextin_create(newWarnLimit, setup, subwin, 1,
+				      BUT_DRAWABLE|BUT_PRESSABLE,
+				      tmpWarnLimit, 10);
+
   setup->help = butCt_create(cgoban_createHelpWindow, &help_configure,
 			     setup->win, 1,
 			     BUT_DRAWABLE|BUT_PRESSABLE, msg_help);
@@ -304,7 +313,7 @@ static ButOut  subwinResize(ButWin *win)  {
 	     w - (w/2 + bw*2), fontH * 2);
 
   y += boxHeight(8, fontH, bw) + fontH * 2;
-  but_resize(setup->miscBox, 0, y, w, boxHeight(5, fontH, bw));
+  but_resize(setup->miscBox, 0, y, w, boxHeight(6, fontH, bw));
   but_resize(setup->miscTitle, bw*2, y + textOff(0, fontH, bw),
 	     w - bw*4, fontH * 2);
   but_resize(setup->coordLabel, bw * 2, y + textOff(1, fontH, bw),
@@ -327,8 +336,13 @@ static ButOut  subwinResize(ButWin *win)  {
   but_resize(setup->noTypo,
 	     w - (bw*2 + fontH * 2), y + textOff(4, fontH, bw),
 	     fontH * 2, fontH * 2);
+  but_resize(setup->warnLabel, bw * 2, y + textOff(5, fontH, bw),
+	     w - (bw * 4 + fontH * 2), fontH * 2);
+  but_resize(setup->warnLimit,
+	     w/2, y + textOff(5, fontH, bw),
+	     w - (w/2 + bw*2), fontH * 2);
 
-  y += boxHeight(5, fontH, bw);
+  y += boxHeight(6, fontH, bw);
   if (y != butWin_h(win))  {
     butCan_resizeWin(win, butWin_w(win), y, TRUE);
   }
@@ -525,3 +539,14 @@ static ButOut  newSrvNum(But *but, int value)  {
 		FALSE);
   return(result);
 }
+
+static ButOut newWarnLimit(But *but, const char *val) {
+  Setup *setup = but_packet(but);
+  int newVal;
+  Clp *clp = setup->cg->clp;
+
+  newVal = atoi(val);
+  setup->cg->cgbuts.timeWarn = newVal;
+  clp_setInt(clp, "client.warnLimit", newVal);
+  return(0);
+}
