@@ -297,11 +297,13 @@ void  butWin_activate(ButWin *win)  {
     sizeHints->min_width = win->minW;
     sizeHints->min_height = win->minH;
     if (win->minWRatio != 0)  {
-      sizeHints->flags |= PAspect;
+      sizeHints->flags |= (PAspect | PBaseSize);
       sizeHints->min_aspect.x = win->minWRatio;
       sizeHints->min_aspect.y = win->minHRatio;
       sizeHints->max_aspect.x = win->maxWRatio;
       sizeHints->max_aspect.y = win->maxHRatio;
+      sizeHints->base_width = 0;
+      sizeHints->base_height = 0;
     }
     if ((win->wStep != 1) || (win->hStep != 1))  {
       sizeHints->flags |= PResizeInc;
